<template>
    <div class="report-overview">
        <div class="left-content">
            <div class="group-list">
                <div class="list-header">
                    <div style="width: 100%">项目分类</div>
                    <!-- <div style="width: 50%">获奖次数</div> -->
                </div>
                <div :class="['list-item', params.querys[1].value === item.value ? 'active-item' : '']"
                    v-for="(item, index) in prizeClassify" :key="index" @click="listItemClick(item)">
                    <div style="width: 100%">{{ item.name }}</div>
                    <!-- <div style="width: 40%">{{ item.nationwideNum }}</div> -->
                </div>
            </div>
        </div>
        <div class="right-content">
            <el-row :gutter="12">
                <el-col :span="6">
                    <div class="search-label">项目名称：</div>
                    <el-input v-model="params.querys[0].value" clearable suffix-icon="el-icon-search"
                        placeholder="请输入项目名称" style="width: 100%"></el-input>
                </el-col>
                <el-col :span="6">
                    <div class="search-label">主责单位：</div>
                    <el-input v-model="params.querys[2].value" clearable suffix-icon="el-icon-search"
                        placeholder="请输入主责单位" style="width: 100%"></el-input>
                </el-col>
                <el-col :span="6">
                    <div class="search-label">专项小组：</div>
                    <!-- <el-input v-model="params.querys[3].value" clearable suffix-icon="el-icon-search"
                        placeholder="请输入专项小组" style="width: 100%"></el-input> -->
                    <dict-select :popperClass="`big-search-popper`" dictCode="wg_zxxz" v-model="params.querys[3].value"
                        :hasDefaultOption="true" clearable style="width: 100%" placeholder="请选择专项小组" />
                </el-col>
                <el-col class="search-btn" style="width: auto;">
                    <div class="search-label"></div>
                    <el-button class="download" type="primary" icon="el-icon-search" @click="getData(1)">查询</el-button>
                </el-col>
                <el-col class="search-btn" :span="2">
                    <div class="search-label"></div>
                    <el-button v-loading="exportLoading" class="download" icon="el-icon-download" type="primary"
                        @click="downloadEffect">Excel</el-button>
                </el-col>
            </el-row>
            <div class="content-box">
                <div class="right-table">
                    <el-table height="calc(100% - 30px)" ref="dataTable" :data="tableData" id="table-bigger-detail"
                        :element-loading-background="loadingColor" v-loading="tableLoading" class="dialog_table" border
                        style="width: 100%" :header-cell-style="{ 'text-align': 'center' }" highlight-current-row>
                        <el-table-column type="index" label="序号" align="center" width="100">
                        </el-table-column>
                        <el-table-column prop="projectName" label="项目名称">
                        </el-table-column>
                        <el-table-column prop="unitName" align="center" width="200" label="主责单位">
                        </el-table-column>
                        <el-table-column prop="groupName" align="center" width="250" label="专项小组">
                        </el-table-column>
                        <el-table-column label="项目分类" align="center" width="150">
                            <template v-slot="{ row }">
                                {{ getDictName('ljlcqh_xmfl', row.projectType + '') }}
                            </template>
                        </el-table-column>
                        <el-table-column align="center" label="备注" width="100">
                            <template v-slot="{ row }">
                                {{ getDictName('ljlcqh_tjzt', row.propulsiveStatus + '') }}
                            </template>
                        </el-table-column>
                        <el-table-column type="expand" width="1">
                            <template v-slot="{ row }">
                                <el-descriptions :element-loading-background="loadingColor" v-loading="detailsLoading"
                                    :column="1" border :labelStyle="{ width: '.6%' }">
                                    <el-descriptions-item label="工作进展">
                                        {{ detailsData.workProgress }}
                                    </el-descriptions-item>
                                    <el-descriptions-item label="改革成效">
                                        {{ detailsData.results }}
                                    </el-descriptions-item>
                                    <el-descriptions-item label="相关附件" :span="4">
                                        <template>
                                            <FileList :fileList="detailsData.files"
                                                :classified="detailsData.classified == '1'">
                                            </FileList>
                                        </template>
                                    </el-descriptions-item>
                                </el-descriptions>
                            </template>
                        </el-table-column>
                        <el-table-column prop="profileName" label="操作" align="center" width="100">
                            <template slot-scope="scope">
                                <el-link :underline="false" type="primary" class="details-btn"
                                    @click="expandRow(scope.row)">详情</el-link>
                            </template>
                        </el-table-column>
                    </el-table>
                    <pagenation class="pagenation" @currentChange="pageChange" :pageResult="params.pageBean">
                    </pagenation>
                </div>
            </div>
        </div>
    </div>
</template>

<script>
import FileList from '@/components/uploadFile/newFileList.vue'
import pagenation from './pagenation.vue'
import apiList from '@/api/bigScreen/majorView.js'
import utils from '@/utils.js'
export default {
    name: 'sixMeeting',
    components: {
        pagenation,
        FileList,
    },
    props: {
        tableOptions: {
            type: Object,
            default: () => {
                return {}
            },
        },
    },
    data() {
        return {
            exportLoading: false,
            loading: false,
            loadingColor: 'rgba(6, 46, 106, 0.4)',
            tableLoading: false,
            fileLoading: false,
            params: {
                pageBean: {
                    page: 1,
                    pageSize: 20,
                    total: 0,
                    showTotal: true,
                },
                querys: [
                    {
                        group: 'main',
                        operation: 'LIKE',
                        parentGroup: '',
                        property: 'project_Name_',
                        relation: 'AND',
                        value: '',
                    },
                    {
                        group: 'main',
                        operation: 'EQUAL',
                        parentGroup: '',
                        property: 'project_Type_',
                        relation: 'AND',
                        value: '',
                    },
                    {
                        group: 'main',
                        operation: 'LIKE',
                        parentGroup: '',
                        property: 'unit_Name_',
                        relation: 'AND',
                        value: '',
                    },
                    {
                        group: 'main',
                        operation: 'LIKE',
                        parentGroup: '',
                        property: 'group_name_',
                        relation: 'AND',
                        value: '',
                    },
                    {
                        group: 'main',
                        operation: 'LIKE',
                        parentGroup: '',
                        property: 'year(create_time_)',
                        relation: 'AND',
                        value: '',
                    },
                ],
                sorter: []
            },
            tableData: [],
            dataList: [],
            prizeClassify: [],
            detailsLoading: false,
            detailsData: {}
        }
    },
    beforeDestroy() {
        this.$bus.$off('changeDate')
    },
    mounted() {
        this.getData(1)
        this.$bus.$on('changeDate', (searchDate) => {
            this.getData(1)
        })
    },
    created() {
        this.prizeClassify = utils.getDictItemsFromCache('ljlcqh_xmfl')
        this.prizeClassify.unshift({ value: '', name: '所有分类' })
        this.$emit('searchDateChange')
    },
    methods: {
        downloadEffect() {
            this.exportLoading = true
            let data = JSON.parse(JSON.stringify(this.params))
            data.pageBean.pageSize = -1
            apiList.meetMunicipalExport(data, res => {
                this.exportLoading = false
            })
        },
        expandRow(row) {
            let $table = this.$refs.dataTable
            this.tableData.map((item) => {
                if (row.id != item.id) {
                    $table.toggleRowExpansion(item, false)
                    item.expansion = false
                } else {
                    item.expansion = !item.expansion
                    if (item.expansion) {
                        this.getSixMeetingDeatils(item.detailsId)
                    }
                }
            })
            $table.toggleRowExpansion(row)
        },
        getSixMeetingDeatils(id) {
            this.detailsLoading = true
            apiList.getSixMeetingDeatils(id, res => {
                if (res) {
                    this.detailsData = res
                }
                this.detailsLoading = false
            })
        },
        listItemClick({ value }) {
            this.params.querys[1].value = value
            this.getData(1)
        },
        getDictName(code, value) {
            return utils.getDictName(code, value)
        },
        getData(page) {
            this.tableLoading = true
            this.params.pageBean.page = page
            let { year } = JSON.parse(sessionStorage.getItem('searchDate'))
            this.params.querys[4].value = year
            this.tableData = []
            apiList.getSixMeetingTableData(this.params, res => {
                this.params.pageBean.total = res.total
                this.tableData = res.rows
                this.tableLoading = false
            })
        },
        pageChange(key) {
            this.getData(key)
        },
    },
}
</script>
<style lang="scss" scoped>
/deep/.classified {
    font-size: 18px !important;
}

/deep/ .el-table__expand-icon {
    visibility: hidden;
}

/deep/.classified {
    font-size: 14px;
}

/deep/.file-item {
    border: none;

    .file_name {
        height: auto;
        max-width: 70%;
    }

    a {
        .el-link--inner {
            font-size: 19PX !important;
        }
    }

    &:hover {
        background: none;
        color: #fff;

        .file_name {
            color: #fff;
        }
    }
}

/deep/.el-collapse {
    border: none;
}

/deep/.el-collapse-item__wrap {
    background: transparent;
    border: none;
}

/deep/.el-descriptions .is-bordered .el-descriptions-item__cell {
    border-color: #245cf3;
    background: transparent;
    color: #fff;
    font-size: 18PX !important;
}

/deep/.el-table td.el-table__cell div {
    // background: transparent;
}

/deep/.el-table--enable-row-hover .el-table__body tr:hover>td.el-table__cell {
    background: rgba(2, 115, 233, .5) !important;
}


/deep/.el-table--enable-row-hover .el-table__body tr:hover>td.el-table__expanded-cell {
    background: transparent !important;
}

/deep/.dialog_table.el-table tr:nth-of-type(2n + 1) {
    background: transparent;
}

/deep/.el-descriptions__body {
    background: transparent;
}

/deep/.el-collapse-item__header.is-active {
    border-bottom-color: transparent;
    background: transparent;
    color: #245cf3;
    font-size: 20px;
    font-weight: bold;
}

/deep/.el-collapse-item__header {
    background: transparent;
    color: #245cf3;
    font-size: 20PX !important;
    font-weight: bold;
    border: none;
}

/deep/.el-collapse-item__arrow {
    margin: 0;
    font-weight: bold;
}

/deep/.dialog-table-expand label {
    width: 120px;
    color: #fff;
    font-family: SimHei;
}

/deep/.el-table__body tr.current-row>td.el-table__cell {
    background: rgba(2, 115, 233, .5) !important;
}

/deep/.el-table {
    background: transparent;
    border: 1px solid rgba(2, 115, 233, 0.5);
    margin-bottom: 10PX;
}

/deep/.el-table th.el-table__cell.is-leaf,
/deep/.el-table td.el-table__cell {
    border-bottom: 1px solid #245cf3;
}

/deep/.el-table--border th {
    &:nth-last-child(2) {
        border-right: none !important;
    }
}

/deep/.el-table--border th,
/deep/.el-table--border td {
    border-right: 1px solid #245cf3 !important;
    padding: 18px 0;

    &:last-child {
        border-right: none !important;
    }

    * {
        font-size: 18PX !important;
    }
}

/deep/.el-table--border::after,
/deep/.el-table::before {
    width: 0;
    height: 0;
}

/deep/.el-table tr,
/deep/.el-table thead tr,
/deep/.el-table thead tr th {
    background: transparent !important;
}

/deep/.el-table th.el-table__cell>.cell,
/deep/.el-table td>.cell {
    font-size: 18PX !important;
    color: #fff;
}

/deep/.el-table {
    background: transparent;
    border: 1px solid rgba(2, 115, 233, 0.5);
    margin-bottom: 10px;

    ::-webkit-scrollbar-thumb {
        background-color: #114385 !important;
    }

    ::-webkit-scrollbar-track {
        background: #01215a !important;
    }

    ::-webkit-scrollbar {
        background: #01215a !important;
    }
}

/deep/.el-table th.gutter {
    border: none !important;
    border-right: 1px solid #245cf3 !important;
}

/deep/.el-table__expanded-cell {
    background: rgba(1, 72, 148, 0.1) !important;
    padding: 20PX 10PX !important;

    td {
        &:last-child {
            border-right: 1px solid #245cf3 !important;
        }
    }
}
</style>
<style lang="scss" scoped>
.report-overview {
    display: flex;
    height: 100%;
    margin-top: 5PX;
    gap: 10PX;
    box-sizing: border-box;

    .left-content {
        width: 15%;
        height: 100%;
        border: 1px solid #245cf3;
        border-radius: 2PX;

        .list-header {
            display: flex;
            width: 100%;
            text-align: center;
            height: 50PX;
            line-height: 50PX;
            // color: #3399FF;
            background: linear-gradient(180deg, rgba(3, 62, 139, 0) 0%, #033E8B 100%);
            border-image: linear-gradient(90deg, rgba(51.00000075995922, 153.00000607967377, 255, 0), rgba(178.49999696016312, 216.75006687641144, 255, 0.20000000298023224), rgba(51.00000075995922, 153.00000607967377, 255, 0)) 1 1;

            >div {
                font-weight: bold;
                font-size: 19PX;
            }
        }

        .list-item {
            display: flex;
            width: 100%;
            text-align: center;
            align-items: center;
            height: 50PX;
            padding: 0 5PX;
            box-sizing: border-box;
            // line-height: 50PX;

            >div {
                font-size: 20PX;

                &:nth-child(2),
                &:nth-child(3) {
                    font-weight: bold;
                    color: #00D5FF;
                }
            }

            &:nth-child(2n+1) {
                background: #043072;
            }

            &:hover {
                cursor: pointer;
                background: #225092;
            }
        }

        .active-item {
            background: #225092 !important;
        }
    }

    .right-content {
        width: 85%;
        height: 100%;

        >.el-row {
            height: 60PX;
            margin-bottom: 20PX;

            .search-label {
                height: 20PX;
                font-size: 18PX;
                line-height: 20PX;
                margin-bottom: 5px;
            }

            .search-btn {
                /deep/.el-button {
                    height: 40PX;

                    >* {
                        font-size: 18PX;
                    }
                }
            }

            /deep/.el-input__inner {
                color: #fff;
                font-size: 18PX;
                height: 40PX;
                box-sizing: border-box;
                background: transparent;
                border: 1px solid #114385;

                &::placeholder {
                    color: #fff;
                    font-size: 18PX !important;
                }

                &::-webkit-input-placeholder {
                    font-size: 18PX !important;
                }
            }
        }

        .content-box {
            height: calc(100% - 80PX);
            display: flex;
            gap: 10PX;

            .right-table {
                width: 100%;
                height: 100%;
            }
        }
    }

    /deep/ .el-select-dropdown__item {
        background-color: #0d57ac !important;
        color: rgba(230, 247, 255, 0.7);

        span {
            font-size: 14px;
        }
    }

    /deep/ .el-select-dropdown__list {
        padding: 0;
    }

    /deep/ .el-select-dropdown {
        border: solid 1px #0273e9;
        background-color: rgba(1, 47, 115, 0.6);
    }

    /deep/.el-select-dropdown__item.hover,
    /deep/ .el-select-dropdown__item:hover {
        background-color: #025ec0 !important;
    }

    /deep/.el-popper[x-placement^="bottom"] .popper__arrow::after {
        border-bottom-color: #0d57ac;
    }

    /deep/.el-popper[x-placement^="bottom"] .popper__arrow {
        border-bottom-color: #0273e9;
    }
}
</style>
